#
# spec file for package libgweather
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libgweather
Version:        3.34.0
Release:        lp152.3.3.1
Summary:        Library to get online weather information
License:        GPL-2.0-or-later
Group:          Development/Libraries/GNOME
URL:            https://wiki.gnome.org/Projects/LibGWeather
Source0:        https://download.gnome.org/sources/libgweather/3.34/%{name}-%{version}.tar.xz
Source99:       baselibs.conf
# PATCH-FIX-UPSTREAM libgweather-use-after-free-libsoup.patch glgo#GNOME/libgweather#34 mgorse@suse.com -- fix possible use after free.
Patch0:         libgweather-use-after-free-libsoup.patch
# PATCH-FIX-UPSTREAM libgweather-yrno-xml-parser-leak.patch mgorse@suse.com -- fix yrno xml parser leak.
Patch1:         libgweather-yrno-xml-parser-leak.patch
# PATCH-FIX-UPSTREAM libgweather-forecast-attribution-leak.patch mgorse@suse.com -- fix forecast attribution leak.
Patch2:         libgweather-forecast-attribution-leak.patch
# PATCH-FIX-UPSTREAM libgweather-metno-api.patch bsc#1185651 glgo#GNOME/libgweather#82 mgorse@suse.com -- use new metno API.
Patch3:         libgweather-metno-api.patch


BuildRequires:  gobject-introspection-devel
BuildRequires:  gtk-doc
BuildRequires:  intltool
BuildRequires:  meson >= 0.50.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(geocode-glib-1.0)
BuildRequires:  pkgconfig(gio-2.0) >= 2.44.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.13.5
BuildRequires:  pkgconfig(libsoup-2.4) >= 2.44.0
BuildRequires:  pkgconfig(libxml-2.0) >= 2.6.0
BuildRequires:  pkgconfig(vapigen)

%description
This is a library to download weather information from online sources.

%package -n gweather-data
Summary:        Auxiliary schema data for libgweather
Group:          Development/Libraries/GNOME
Requires:       libgweather-3-16 = %{version}
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}
Provides:       libgweather-data = %{version}
Obsoletes:      libgweather-data < %{version}
BuildArch:      noarch

%description -n gweather-data
This is a library to download weather information from online sources.
This package provides the architecture independent files.

%package devel
Summary:        Development files for libgweather, a weather info retrieval library
Group:          Development/Libraries/GNOME
Requires:       libgweather-3-16 = %{version}
Requires:       typelib-1_0-GWeather-3_0 = %{version}

%description devel
This is a library to download weather information from online sources.
This package provides the development files.

%package -n libgweather-3-16
Summary:        Library to get online weather information
Group:          Development/Libraries/GNOME
Requires:       gweather-data >= %{version}

%description -n libgweather-3-16
This is a library to download weather information from online sources.

%package -n typelib-1_0-GWeather-3_0
Summary:        Introspection bindings for libgweather
Group:          System/Libraries

%description -n typelib-1_0-GWeather-3_0
This is a library to download weather information from online sources.

This package provides the GObject Introspection bindings for the
libgweather library.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-Dglade_catalog=false \
	-Denable_vala=true \
	-Dgtk_doc=true \
	%{nil}
%meson_build

%install
%meson_install

%find_lang libgweather-3.0 %{?no_lang_C}
%find_lang libgweather-locations libgweather-3.0.lang %{?no_lang_C}

%post -n libgweather-3-16 -p /sbin/ldconfig
%postun -n libgweather-3-16 -p /sbin/ldconfig

%files -n gweather-data
%{_datadir}/glib-2.0/schemas/org.gnome.GWeather.enums.xml
%{_datadir}/glib-2.0/schemas/org.gnome.GWeather.gschema.xml
%{_datadir}/libgweather/

%files -n libgweather-3-16
%license COPYING
%{_libdir}/*.so.*

%files -n typelib-1_0-GWeather-3_0
%{_libdir}/girepository-1.0/GWeather-3.0.typelib

%files devel
%doc AUTHORS HACKING MAINTAINERS README README.md NEWS
%doc %{_datadir}/gtk-doc/html/libgweather
%{_includedir}/libgweather-3.0
%{_libdir}/*.so
%{_libdir}/pkgconfig/gweather-3.0.pc
%{_datadir}/gir-1.0/GWeather-3.0.gir
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/gweather-3.0.deps
%{_datadir}/vala/vapi/gweather-3.0.vapi

%files lang -f %{name}-3.0.lang

%changelog
* Fri Jun  4 2021 Michael Gorse <mgorse@suse.com>
- Add libgweather-use-after-free-libsoup.patch: fix a possible use
  after free (glgo#GNOME/libgweather#34).
- Add libgweather-yrno-xml-parser-leak.patch and
  libgweather-forecast-attribution-leak.patch: fix memory leaks,
  taken from upstream gnome-3-34 branch.
- Add libgweather-metno-api.patch: use new metno API (bsc#1185651
  glgo#GNOME/libgweather#82).
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Tue Oct  8 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.0:
  + Updated translations.
* Thu Sep  5 2019 mgorse@suse.com
- Update to version 3.33.92:
  + This version fixes a bug when using the yr.no and NOAA weather
    services together failing in some circumstances, and also fix
    the iwin service.
- Now requires meson >= 0.50.0.
* Sat Aug 31 2019 mgorse@suse.com
- Update to version 3.33.0:
  + This version of the library bumps the soname after an ABI break
    in 3.28.0 that went unnoticed. If you see strange crashes,
    make sure to bump the required version of libgweather to 3.28.0
    or newer.
- Update package name for the API version bump.
- Up meson requirement to 0.48.0 and glib requirement to 2.44.0.
* Thu Jul  4 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.2:
  + Fix a memory leak.
  + Fix deserialisation of a city.
  + Updated translations.
* Wed Mar 20 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.1:
  + Fix location deserialisation not working for locations without
    a weather station code (eg. cities).
  + Make more debug available for weather fetching.
  + Updated translations.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Fix a warning when the location text entry is used.
  + Remove closed Bristol Filton weather station.
  + Updated translations.
* Fri Feb 22 2019 bjorn.lie@gmail.com
- Update to version 3.31.91:
  + Disconnect cities from weather stations and remove duplicated
    weather stations.
  + Remove <province> sub-division.
  + Location database updates.
* Fri Feb 22 2019 bjorn.lie@gmail.com
- Update to version 3.28.3:
  + Fix METAR weather extraction.
  + Fix multilib problem in enum header.
  + Fix infinite loop calculating sunset/sunrise for named
    timezones.
  + Fix a possible crash in gnome-shell.
  + Fix "nearest station" fallback code.
  + Updated translations.
* Fri Jun 15 2018 bjorn.lie@gmail.com
- Update to version 3.28.2:
  + Fix crash in gnome-shell.
  + Updated translations.
- Cleanup spec, drop la files rm, no longer needed when building
  with meson.
* Sun Mar 25 2018 luc14n0@linuxmail.org
- Update to version 3.28.1:
  + Fix memory and D-Bus match rule leaks.
  + Updated translations.
* Fri Mar  9 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Fix translations not being used (bgo#794027).
  + Location database updates and fixes for Israel.
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Jan  9 2018 luc14n0@linuxmail.org
- Update to version 3.27.4:
  + Deprecated API was removed (bgo#791313).
  + New API: a new level of locations, called "named timezones" was
    added (bgo#791066).
  + It is now possible to have cities in the database with no
    associated weather station; the nearest weather station is
    chosen if necessary.
  + Matching of search terms to location names was improved
    (bgo#791066, bgo#791403).
  + The Yahoo Weather backend was removed (bgo#791084).
  + More tests were added (bgo#791307, bgo#791313, bgo#791317,
    bgo#791319, bgo#791402).
  + Misc bug fixes (bgo#789080).
  + Build system fixes (bgo #791088, #791086).
  + Translation bug fixes (bgo#781364).
  + Location database updates and fixes (bgo#791095, bgo#620897,
    bgo#727186, bgo#643928, bgo#789951, bgo#791323, bgo#599880,
    bgo#642634, bgo#606557, bgo#617689, bgo#768309, bgo#635534,
    bgo#597989, bgo#625270, bgo#625270, bgo#583644, bgo#534047,
    bgo#572675, bgo#611945, bgo#640877, bgo#778707).
  + Updated translations
- Changes from version 3.27.1:
  + This is the first version to use the meson build system.
  + Updated translations
- Update Url to https://wiki.gnome.org/Projects/LibGWeather:
  current LibGWeather project's web page.
- Drop libgweather-locations-Kowloon-is-a-district.patch: fixed
  upstream.
- Drop libxml2-tools and libxslt BuildRequires: there is no reason
  for them to be explicitly declared since both of them are pulled
  with gtk-doc
- Add meson BuildRequires and replace configure, make_build and
  make_install macros by meson, meson_build and meson_install
  respectively; and pass enable_vala, gtk_doc option as true and
  glade_catalog option as false. All of these changes reflects
  upstream's port to the Meson build system.
- Add gio-2.0 and libxml-2.0 pkgconfig modules BuildRequires: Note
  that they were being pulled and used already but not explicitly
  declared.
- Drop %%glib2_gsettings_schema_requires macro: it's no longer
  needed since RPM file triggers.
* Sat Dec  2 2017 zaitor@opensuse.org
- Update to version 3.26.1:
  + Updated translations.
- Modernize spec, run spec-cleaner, use autosetup and make_build
  macros.
- Drop glib2_gsettings_schema_post and icon_theme_cache_post(un)
  from post(un) handling, filetriggers takes care of this now.
- Add libgweather-locations-Kowloon-is-a-district.patch: Kowloon is
  a district in the city of Hong Kong. Not a town (bgo#791095).
- Drop old and long unneeded obsoletes and provides:
  gnome-applets-devel and gswitchit-devel.
- Package missing COPYING again.
- Rename libgweather-data sub-package to gweather-data; change
  corresponding Requires in other packages, and add
  libgweather-data < %%%%{version} Obsoletes and libgweather-data =
  %%%%{version} Provides.
- Add gtk-doc BuildRequires and pass --enable-gtk-doc to configure:
  Build the documentation our selves, and not rely on the
  pre-packaged ones in the tarball.
* Mon Sep 11 2017 jengelh@inai.de
- Update package summaries. Replace old RPM macros.
* Mon Sep 11 2017 zaitor@opensuse.org
- Update to version 3.26.0:
  + Updated translations.
* Wed Sep  6 2017 dimstar@opensuse.org
- Update to version 3.25.92:
  + Location database fixes.
  + Updated translations.
* Sun Aug 20 2017 zaitor@opensuse.org
- Update to version 3.35.91:
  + New API to show uncapitalized weather (bgo#779872).
  + Memory management fixes (bgo#781828).
  + User visible string fixes (bgo#785274).
  + Location database updates and fixes (bgo#780244).
  + Updated translations.
- Drop libgweather-dont-release-allocated-memory.patch: Fixed
  upstream.
* Mon Jun  5 2017 zaitor@opensuse.org
- Update to version 3.24.1:
  + Memory management fixes: bgo#780278, bgo#782760.
  + Updated translations.
- Add libgweather-dont-release-allocated-memory.patch: location:
  Don't release libxml-allocated memory with g_free() (bgo#781828).
  This commit was missed in the release.
* Mon Mar 20 2017 zaitor@opensuse.org
- Update to version 3.24.0:
  + New API to find a country by code (bgo#753332).
  + Location entry now respects country when choosing the closest
    weather station (bgo#753332).
  + Misc bug fixes: bgo#776170, bgo#770979, bgo#772758.
  + Location database updates and fixes: bgo#775737, bgo#776337,
    bgo#770579.
  + Updated translations.
* Thu Dec 22 2016 zaitor@opensuse.org
- Update to version 3.20.4:
  + Updated translations.
* Mon Aug 29 2016 zaitor@opensuse.org
- Update to version 3.20.3:
  + NOAA shut down their METAR provider service, so libgweather
    switched to a different provider (bgo#770321).
  + Updates translations.
- Drop libgweather-change-service-provider.patch: Fixed upstream.
* Fri Aug 26 2016 badshah400@gmail.com
- Add libgweather-change-service-provider.patch: The existing
  weather service provider was expired, replace by a working
  provider instead; patch taken from upstream bug report
  (bgo#770321).
* Tue Aug 23 2016 zaitor@opensuse.org
- Spellfix in find_lang macro.
- Drop obsolete clean section.
* Tue Aug 16 2016 dimstar@opensuse.org
- Update to version 3.20.2:
  + Fixed NOAA API URL (bgo#765322).
  + Updated translations.
* Mon May  9 2016 zaitor@opensuse.org
- Update to version 3.20.1 (fate#318572):
  + Updated translations.
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
- Drop libgweather-location-search-i18n.patch,
  libgweather-soup-abort-in-dispose.patch,
  libgweather-soup-no-abort-session.patch, and
  libgweather-yrno19.patch: fixed upstream.
* Tue Mar 22 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + Update to new yr.no API (bgo#763175).
  + Updated translations.
* Tue Feb 16 2016 dimstar@opensuse.org
- Update to version 3.19.90:
  + Build system updates.
  + Fix build with Clang (bgo#760178).
  + libsoup dependency bumped to 2.44.
  + Updated translations
* Tue Dec 15 2015 fcrozat@suse.com
- Replace gtk3-devel/libsoup-devel BuildRequires with their
  pkgconfig equivalent.
* Mon Oct 12 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Build system fixes.
  + Updated translations.
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Sat Sep 12 2015 zaitor@opensuse.org
- Update to version 3.17.92:
  + Updated translations.
* Tue Jul 28 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + New API to resolve default values for units (only temperature
    for now).
  + Reduced use of deprecated APIs.
  + Updated translations.
* Tue May 12 2015 dimstar@opensuse.org
- Update to version 3.17.1:
  + API break: some include files were renamed, and single includes
    are now mandatory. Binary compatibility was preserved.
  + Misc bug fixes to the search in the database (bgo#748299).
  + Location database fixes (bgo#747155).
  + Build system updates to improve operation with GNOME Builder.
  + Build system fixes (#747837, bgo#747890).
- Drop libgweather-LocationEntry-fix-database.patch: Fixed
  upstream.
* Tue May 12 2015 zaitor@opensuse.org
- Add libgweather-LocationEntry-fix-database.patch: LocationEntry:
  fix database matching in the presence of whitespace. Patch from
  upstream git.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + Updated translations.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Tue Mar 17 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Improved integration with geocode-glib (which avoids showing
    the country name twice now).
  + Misc bug fixes.
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Updated translations.
* Mon Feb 16 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + New API: gweather_location_new_detached(), for easier
    integration with services that provide only a description,
    latitude and longitude.
  + New and improved documentation.
  + Updated translations.
* Tue Jan 27 2015 badshah400@gmail.com
- Update to version 3.15.1:
  + Location database fixes (bgo#743092, bgo#743111, bgo#743112).
  + Updated translations.
* Tue Jan 27 2015 dimstar@opensuse.org
- Update to version 3.14.3:
  + Location database fixes (bgo#743092, bgo#743111, bgo#743112).
  + Updated translations.
* Sun Dec 21 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + Fixed a crash in the location entry (bgo#739899).
  + Location database fixes (bgo#740932, bgo#721446).
  + Updated translations.
* Thu Dec 18 2014 fcrozat@suse.com
- Add libgweather-yrno19.patch: use Yr.no API 1.9, older API is
  deprecated (bsc#910688).
* Mon Oct 13 2014 zaitor@opensuse.org
- Update to version 3.14.1:
  + The yahoo weather backend now uses HTTPS for privacy
    (bgo#737566).
  + The yr.no weather backend was fixed (it regressed in 3.13.92)
    (bgo#738307).
  + Updated translations.
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Tue Sep 16 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + The yr.no backend has been updated to the 1.9 API (bgo#736334).
  + Updated translations.
* Wed Sep 10 2014 mgorse@suse.com
- Add libgweather-location-search-i18n.patch: fix searching for
  locations in non-ENglish locales (bnc#895068).
* Mon Sep  1 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + Fixed timezones of all cities (used in gnome-clocks, among
    others) (bgp#734272).
  + Misc bug fixes and utility API additions (bgo#734876).
  + Location database fixes.
  + Updated translations.
* Tue Aug 19 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + GWeatherLocationEntry no longer shows different airports for
    the same city separately (bgo#732315).
  + Misc bug fixes (bgo#732728).
  + Location database fixes (bgo#721134).
  + Updated translations.
* Tue Jul 22 2014 dimstar@opensuse.org
- Add pkgconfig(vapigen) BuildRequires: enable vala bindings.
* Tue Jul 22 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Expanded the range of cities offered in the location entry
    through the use of geocode-glib (bgo#731466).
  + Misc bug fixes.
  + Location database fixes (bgo#733269).
  + Updated translations.
* Sun Jul 20 2014 mgorse@suse.com
- Include vala bindings in devel package..
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + Removed support for moon phase icons, and removed the icons
    from the package.
  + Fixed GWeatherLocationEntry localization (bgo#726897).
  + Location database fixes (bgo#731394).
- Changes from version 3.13.2:
  + Serialization format for locations was changed. Existing
    serialized locations are recognized, but variants produced by
    the new library are not compatible. The new format is
    compatible with dbus-1, so locations can now be sent across
    dbus.
- Changes from version 3.13.1:
  + Added support for a find_nearest_city() method that takes a
    filter function (bgo#726186).
  + Added support for reverse geocoding to find_nearest_city()
    (bgo#725842).
  + Build and warning fixes.
  + Updated translations.
- Add pkgconfig(geocode-glib-1.0) BuildRequires: new dependency.
- Drop gnome-icon-theme Requires from -data package: the icon
  themes gnome-icon-theme and gnome-icon-theme-symbolic have been
  merged into adwaita-icon-theme, which in turn is guaranteed to
  be present on GTK3 installations.
- Drop gnome-icon-theme BuildRequires: no longer needed.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Updated translations.
* Tue Apr 15 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Updated translations.
* Fri Mar 28 2014 mgorse@suse.com
- Add libgweather-soup-abort-in-dispose.patch: abort soup session
  in dispose, not finalize. From upstream gnome-3-10 branch.
- Add libgweather-soup-no-abort-session.patch: Don't abort entire
  soup session. From upstream gnome-3-10 branch.
* Wed Mar 26 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Wed Mar 19 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Fixed SoupSession handling with multiple GWeatherInfos.
  + Miscellaneous bug fixes (bgo#725671).
  + Location database additions (bgo#707603, bgo#726016).
  + Build fixes.
  + Updated translations.
* Tue Mar  4 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Add a version information API (bgo##724676).
  + Improved developer documentation.
  + Updated translations.
* Sat Feb 22 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Unset the location when the entry is cleared (bgo#724416).
  + Location database additions (bgo#722625).
  + Updated translations.
* Sat Feb 22 2014 dimstar@opensuse.org
- Update to version 3.11.5:
  + Location database additions (bgo##721446, bgo#720871,
    bgo#720777, bgo#722301).
  + Fixed invalid yr.no URLs.
  + Updated translations.
* Sat Feb 22 2014 dimstar@opensuse.org
- Update to version 3.11.4:
  + Updated translations.
* Sat Feb 22 2014 dimstar@opensuse.org
- Update to version 3.11.3:
  + Restore support for systems without _NL_MEASUREMENT_MEASUREMENT
    (BSDs).
  + Add utility function to find the nearest city (bgo#677268).
  + Add method to get the timezone by ID.
  + C standard and build warning fixes fixes (bgo#720207,
    bgo#720208).
  + Database updates.
  + Updated translations.
* Fri Feb 21 2014 zaitor@opensuse.org
- Update to version 3.10.2:
  + Location database additions (bgo#721446, bgo#720871,
    bgo#720777, bgo#722301).
  + Updated translations.
* Tue Oct 15 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Misc bug fixes (bgo#708586).
  + Updated translations.
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Mon Sep 16 2013 firebird209@gmail.com
- Update to version 3.9.92:
  + Updated translations.
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Add optional vala support.
  + Location database fixes.
  + Updated translations.
* Mon Aug 19 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Location database fixes.
  + Updated translations.
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 3.9.5:
  + Translations for the locations database are now stored in
    separate mo files and looked up at runtime, cutting build times
    and installed size.
  + A number of minor API breaks, such as the removal of
    forecast-type GObject property and accessors; most apps still
    build fine.
  + New backend: OpenWeatherMap.
  + Updated translations.
- Changes from version 3.9.4:
  + Fixed handling of detached locations.
  + Updated translations.
- No longer pass --enable-locations-compression to configure: the
  parameter no longer exists, as the translations for the locations
  database are now stored in .mo files instead of xml files.
- Drop libgweather-bnc428346-bundle.patch: as there are no xml
  files installed, there is also no need to look for them in the
  bundle lang directories.
- Remove spec hacks that were needed for the Locations.xml
  handling.
- Drop translation-update-upstream BuildRequires: no longer needed.
- Rename libgweather-3-5 subpackage to libgweather-3-6, following
  upstreams soname change (also in baselibs.conf).
* Fri Jun 21 2013 dimstar@opensuse.org
- Update to version 3.9.3:
  + ABI break: GWeatherLocationEntry now is a subclass of
    GtkSearchEntry.
  + Location database fixes.
  + Updated translations.
- Rename libgweather-3-3 subpackage to libgweather-3-5, following
  upstreams soname change (also in baselibs.conf).
* Wed May 29 2013 dimstar@opensuse.org
- Update to version 3.9.2:
  + There is now a single hierarchy of GWeatherLocation structures,
    and gweather_location_new_world() returns a singleton object.
  + Therefore, constructors which accepted a @world parameter have
    been deprecated.
  + GWeatherInfo now emits ::updated in response to GSettings
    changes.
  + A Glade catalog was added, covering the Gtk widgets.
  + Updated translations.
- Changes from version 3.9.1:
  + Miscellaneuous fixes to the METAR, Yahoo and yr.no backends.
  + GWeatherLocationEntry will autocomplete when pressing enter
    (if activates-default is true).
  + GWeatherInfo now enables automatic disk caching of network
    request and gzip encoding (where available).
  + New API added to flush the cache to disk, only for language
    bindings with a GC (ie JS). C, Vala or Python apps get this
    for free.
  + Default measure units are now derived from LC_MEASUREMENTS,
    not LC_MESSAGES, thus respecting the configuration in the
    Region & Language control center panel.
  + Updated translations.
* Mon May 13 2013 dimstar@opensuse.org
- Update to version 3.8.2:
  + Fix some timezone issues in Russia.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Updated translations.
* Tue Mar 26 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Mon Mar 18 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Various fixes to parsing of weather data from network services.
  + Updated translations.
* Tue Mar  5 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + GWeather date and time format now use proper Unicode characters
  + Updated translations.
* Mon Feb 18 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + Added a gweather.h global include, which is also referenced
    from the GIR file.
  + Fixed introspection annotations.
  + Fixed sunrise and sunset getters requiring forecast data.
  + Added translation context to ambiguous strings.
  + Updated translations.
* Mon Feb  4 2013 dimstar@opensuse.org
- Update to version 3.7.5:
  + Updated translations.
* Tue Jan 15 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + We no longer use libsoup-gnome, and instead depend on a newer
    libsoup (>= 2.34) which uses libproxy to access proxy
    configuration.
  + Location update scripts have been ported to Python 3.
* Tue Jan  8 2013 dimstar@opensuse.org
- Update to version 3.7.3:
  + Two new backends for GWeatherInfo: Yahoo! Weather
    and Yr.no. Work has started to include Yahoo location data
    (WOEID) in the offline database.
  + GWeatherInfo backends can now be enabled and disabled
    individually from the application side.
  + GWeatherXML was removed from the public API. No users of it are
    known, however the soname was bumped.
  + GWeatherLocation is now serializable to GVariant for storage in
    GSettings.
  + GWeatherInfo no longer requires network access for astronomical
    data.
  + Unmaintained Windows support was removed.
  + Updated translations.
- Rename libgweather-3-1 subpackage to libgweather-3-3, according
  shared library packaging policy (also in baselibs.conf).
* Sun Nov 25 2012 dimstar@opensuse.org
- Update to version 3.7.2:
  + Fixed deprecation warnings for modern GLib.
  + Updated translations.
* Tue Nov 13 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + Updated translations.
* Mon Oct 15 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Updated translations.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Updated translations.
* Tue Sep 18 2012 dimstar@opensuse.org
- Update to version 3.5.92:
  + Updated translations.
* Mon Sep  3 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + Updated coordinates of two Italian cities
  + Updated translations.
* Mon Aug 20 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + Updated translations.
* Mon Aug  6 2012 dimstar@opensuse.org
- Update to version 3.5.5:
  + Updated translations.
* Tue Jul 17 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + Updated translations.
- Changes from version 3.5.1:
  + libgweather:
  - Various introspection updates and fixes
  - GWeatherLocation is now a boxed type and used as such through
    out the library
  - Each GWeatherLocation is now strongly associated with world
    level location, and this is reflected in GWeatherInfo
  - Fixed retrieving US weather for non US locales
  - Applied symbol filtering to avoid exposing non public API
  + Updated translations.
- Changes from version 3.5.0:
  + libgweather: Port to GSettings
  + Misc:
  - Use upstream gettext
  - Autotools build system fixes
  + Updated translations.
- Drop gconf2-devel BuildRequires: ported to gsettings.
- Replace %%gconf_* schema handling macros with %%glib2_*
  equivalents, following the port to GSettings.
- Remove --disable-schemas-install configure parameter, as it is
  no longer known to configure after the port to GSettings.
- Rename libgweather-3-0 to libgweather-3-1, following upstreams
  soname bump.
- Update baselibs.conf, following the new package names.
* Fri Mar  9 2012 dimstar@opensuse.org
- Update to version 3.4.1:
  + Link with libm explicitly
  + Set the URL for the package's home page in AC_INIT
- Drop libgweather-libm.patch: fixed upstream.
* Wed Mar  7 2012 dimstar@opensuse.org
- Update to version 3.4.0:
  + Move API documentation to inline comments
  + Improve autotools configuration a bit
  + Updated translations.
- Add libgweather-libm.patch: link against libm where needed.
* Sun Feb 26 2012 dimstar@opensuse.org
- Add libxml2-tools BuildRequires: libxml2 was split according to
  SLPP, which means xmllint is no longer pulled in automatically.
* Thu Dec  8 2011 dimstar@opensuse.org
- Split typelib file into typelib-1_0-GWeather-3_0 subpackage.
- Add typelib-1_0-GWeather-3_0 Requires to devel subpackage.
* Tue Oct 25 2011 vuntz@opensuse.org
- Update to version 3.2.1:
  + Fix fetching forecast from bom.gov.au
  + Fix fetching forecasts from the Met Office
  + Fix introspection build with builddir != srcdir
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Updated translations.
- Change libgweather Obsoletes from <= to < in libgweather-data,
  since we have a new upstream version.
* Mon Jul  4 2011 vuntz@opensuse.org
- Update to version 3.1.3:
  + Modernize build system a bit
  + Updated translations.
* Tue May 24 2011 dimstar@opensuse.org
- Update to version 3.0.2:
  + Updated translations.
* Fri May  6 2011 nmarques@opensuse.org
- bnc#692048: Move data files from main package to -data subpackage
  - data package Provides/Obsoletes the main package for a smooth
  upgrade path.
- Clean spec file using spec-cleaner.
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Build fixes
  + Updated translations.
* Mon Feb 14 2011 fcrozat@novell.com
- Update to version 2.91.6:
  - Fix linking with gcc-4.5
  - Updated translations.
- Changes from version 2.91.0:
  - Port to GTK+ 3
  - Add introspection support
  - Remove python bindings
  - Update for tzdata 2010k
- Change gtk2-devel BuildRequires to gtk3-devel.
- Add gobject-introspection-devel BuildRequires.
- Remove python-devel, python-gobject2-devel, python-gtk-devel
  BuildRequires that were only needed for python bindings.
- Rename libgweather1 to libgweather-3-0.
- Remove explicit Requires of dbus-1-glib-devel, gconf2-devel,
  glib2-devel, gtk2-devel, libsoup-devel in devel package: they
  will automatically be added the pkgconfig() way.
- Drop python-gweather subpackage.
- Change --enable-python to --enable-introspection in configure
  call.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.30.3:
  + Locations.xml.in: Update for tzdata 2010k
  + Updated translations.
* Thu Jul  8 2010 dimstar@opensuse.org
- Update to version 2.30.2:
  + Updated translations.
* Fri Jun  4 2010 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Tue Mar 30 2010 vuntz@opensuse.org
- Update to version 2.30.0:
  + Updated translations.
* Tue Mar  9 2010 dimstar@opensuse.org
- Update to version 2.29.92:
  + Updated translations.
* Tue Feb 23 2010 vuntz@opensuse.org
- Update to version 2.29.91:
  + Locations.xml.in
  - Mulhouse, FR and Basel, CH
  - Boulder, CO, US
  - Castle Donington, UK
  - Taiwan cities
  - Canberra, AU
  - St. Moritz, CH and Ankara, TR
  - Antartica
* Wed Feb 10 2010 vuntz@opensuse.org
- Update to version 2.29.90:
  + Locations.xml.in:
  - Lodz, PL
  - Abuja, NG
  - Tbilisi, GE
  - Krasnoyarsk, RU
  - Port-au-Prince, HT
  + Updated translations.
- Fix self-obsoletion of gnome-applets-devel.
* Thu Jan 14 2010 captain.magnus@opensuse.org
- Update to version 2.29.5:
  + Translation updates
* Tue Jan  5 2010 jengelh@medozas.de
- Package baselibs.conf
* Wed Dec 23 2009 vuntz@opensuse.org
- Update to version 2.29.4:
  + libgweather
  - Unwind change that limited each city to one location
  - Add entries missing from data/major-cities.txt
  + Locations.xml.in
  - Many location fixes.
  + Updated translations.
- Changes from version 2.29.3:
  + libgweather
  - Phase-of-moon support, icons
  - Remove check for obsolete tzdata identifiers
  - Fix 'radar' spelling
  + Updated translations.
- Add BuildRequires and Requires for gnome-icon-theme, needed for
  directory ownership.
* Thu Dec 10 2009 aj@suse.de
- Remove unneeded gnome-vfs2-devel Requires from devel package.
* Tue Sep 22 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  + Improve configure summary
  + Use pygobject-codegen-2.0 instead of pygtk-codegen-2.0
  + Updated translations.
* Mon Sep 14 2009 vuntz@opensuse.org
- Use python_sitearch to fix build on x86_64.
* Wed Sep  9 2009 vuntz@opensuse.org
- Update to version 2.27.92:
  + Fix compiler warning
  + Do not set executable bit for __init__.py
  + Fix out-of-tree build
  + Updated translations.
- Build python bindings, and package them in python-gweather.
- Add python-devel, python-gobject2-devel, python-gtk-devel
  BuildRequires.
* Wed Aug 26 2009 vuntz@novell.com
- Update to version 2.27.91:
  + libgweather
  - More work for the windows port
  - Replace svn.gnome.org references by git.gnome.org
  - Add gweather_timezone_get_utc() to get the UTC timezone
  - Add the UTC timezone in the timezone menu
  - Make gweather_location_entry_set_city() return a boolean
  - Add gweather_location_entry_has_custom_text() API
  + Misc
  - Check for regex library
  - Use silent-rules for quiet build
  - Build fixes
  + Updated translations.
* Mon Jul 20 2009 vuntz@novell.com
- Update to version 2.26.2.1:
  + libgweather
  - Make it work on Windows
  + Misc
  - Use shave to improve build log readability
  - Check for regex library
  + Updated translations.
* Tue Apr 14 2009 vuntz@novell.com
- Update to version 2.26.1:
  + Don't crash if the user provided an invalid URL for the radar
    check.
  + Updated translations.
* Tue Mar 17 2009 vuntz@novell.com
- Update to version 2.26.0:
  + Locations.xml
  - Remove a duplicate copy of Warsaw
  - Strip out the automated Canadian stations that (badly)
    duplicate non-automated stations. This fixes Edmonton
  - Regenerate with only currently-reporting locations. This
    fixes Berlin
  + Updated translations.
* Sun Mar  8 2009 vuntz@novell.com
- Review changes.
* Wed Mar  4 2009 lmedinas@gmail.com
- Update to version 2.25.92:
  + Mark "Unknown" as translatable in the timezone menu
  + Translation updates
* Thu Feb 26 2009 vuntz@novell.com
- Use find_gconf_schemas instead of some add_gconf_schemas for
  clarity, but also because we can potentially make it faster.
* Tue Feb 17 2009 mboman@suse.de
- Update to version 2.25.91:
  + Locations.xml
  * Use Asia/Kathmandu instead of Asia/Katmandu
  + Misc
  * Make it easier to regenerate locations.pot
  + Translation updates
- Move gtk-doc from main package to -devel
- Remove gtk-doc from BuildRequires
* Fri Feb  6 2009 hfiguiere@suse.de
- Review and approve.
* Wed Jan 28 2009 lmedinas@gmail.com
- Update to version 2.25.5:
  + Translation updates
* Wed Jan 21 2009 crrodriguez@suse.de
- remove "la" files
* Tue Jan  6 2009 msuman@suse.de
- Update to version 2.25.4:
  + Misc. bug fixes
  + Updated translations
* Sat Dec 20 2008 mboman@suse.de
- Update to version 2.25.3:
  + Make libgweather work on Win32
  + Improve regeneration framework for po file for Locations.xml
  + Add new API to directly get WeatherInfo values instead of strings
  + Use the degree sign followed by "C" or "F" rather than using the
    combined "degrees C" and "degrees F" glyphs
  + Handle wind reports in m/s
  + Use new libsoup 2.25.1 API for proxy instead of some custom code
  + Use single includes for gtk/glib
  + Do not use deprecated libsoup API
  + Do not care about sub-city locations and only use the first child
  + Handle compressed Locations.xml files
  + Code cleanups
  + Do not localize sub-city locations since they won't be used in the UI
  + Add "Bahamas" to the list of countries whose name we put "the" before
    in comments
  + Add msgctxt attributes to the XML for duplicate names
  + When given a location name like "Covington / Cincinnati", only create
    an entry for one of the two cities
  + Fix spelling of local vs international names
  + Do not assume a weather station is in the same country as a city.
    This fixes Luxembourg not appearing in the list of countries
  + Make sure that the shipped COPYING file is GPLv2
  + Add various flags like -DG_DISABLE_SINGLE_INCLUDES and
    _DISABLE_DEPRECATED flags
  + Remove locations_file from the pkg-config pc file
  + Require intltool 0.40.3
  + Add --enable-locations-compression configure flag to compress
    Locations.xml files with gzip
  + Add some (incomplete) API documentation with gtk-doc
- Remove libgweather-bnc428346-compress.patch. Fixed upstream
* Sun Nov 30 2008 vuntz@novell.com
- Add libgweather-bnc428346-bundle.patch to support shipping
  Locations.xml files in bundle-lang-gnome-$locale without
  conflicting with libgweather-lang: bundle-lang-gnome-$locale will
  use another directory.
* Mon Nov 24 2008 vuntz@novell.com
- Add libgweather-bnc428346-compress.patch to compress
  Locations.xml files.
- Move Locations.$locales.xml data to the lang package.
- This makes libgweather smaller, and libgweather-lang much bigger
  (especially since compressing each Location.xml files results in
  a compression loss in the final rpm -- it's more efficient to
  compress several xml files together than separately), but this
  makes it possible to have those files end in the
  bundle-lang-gnome-$locale packages. So in the end, it's a win.
  Fix bnc#428346.
* Wed Oct 22 2008 vuntz@novell.com
- Update to version 2.24.1:
  + Make sure the returned strings are UTF-8
  + Code cleanups
  + Fix crash if a timezone in Locations.xml is not known
  + Use the proxy settings
  + Add weather_info_network_error() API to know the type of error
    when getting the weather
  + Mexican states of Chihuahua, Nayarit, Sinaloa, and Sonora are
    in Mountain Time, not Central Time
  + Distribute gweather.defs so python bindings are buildable
  + Add -lm to the build
  + Updated translations.
* Tue Sep 23 2008 maw@suse.de
- Update to version 2.24.0:
  + Updated translations.
* Fri Sep 12 2008 maw@suse.de
- Update to version 2.23.92:
  + Add python bindings (not enabled in this build)
  + Updated translations.
* Wed Sep  3 2008 mboman@novell.com
- Update to version 2.23.91:
  + Fix build with old gcc
  + Parse decimal degrees rather than d/m/s
  + Fix a regexp to not mangle the spacing around "/" in some cases
  + Fix various comments in Locations.xml
  + Drop a lot of cities that are not useful in this database
  + Make <coordinates> use decimal degrees rather than converting them to
    degrees/minutes/seconds
  + Fix Bangkok, Thailand
  + Fix typo in MMGL so it appears again
  + Make --with-zoneinfo-dir configure flag work
  + Build system fixes for Locations.xml
  + Add a gweather-uninstalled.pc.in file
  + Update translations
* Thu Aug 28 2008 maw@suse.de
- Update to version 2.23.6:
  + Use libsoup for http
  + Make the XML parsing more future-proof
  + Fixes weather information not showing up in the clock applet
  + Use a new Locations.xml.in parser
  + Add GWeatherTimezone type to represent a timezone
  + Add GWeatherLocation type to represent a location; it will
    eventually replace WeatherLocation
  + Add new GWeatherLocationEntry widget to select a location
  + Add new GWeatherTimezoneMenu widget to select a timezone
  + Locations.xml:
  * Fix spelling of Ulaanbaatar, Mongolia
  * Remove duplicate copy of Gadsden, Alabama, US and of other
    locations
  * Fix BOM codes for Alice Springs and Darwin, Australia
  * Reorganize Brazil into <state>s, with proper timezone hints
  * Fix South African locations to not be based on out-of-date
    airport names
  * AddŁód, Poland
  * Split "Serbia and Montenegro" into "Serbia" and "Montenegro"
  * Move various locations to the right country or continent
  * Mark some locations as translatable
  * Reorganize countries exactly according to ISO 3166
  * ?Rework:
    > The file can be easily regenerated with some scripts
    > Tvery <location> node is inside a <city> node with a real
    city name
    > We should have better & more consistent data now
  * Add information about timezones
  + Updated translations.
* Wed Jun 18 2008 maw@suse.de
- Update to version 2.23.4:
  + Use the new URL for the Weather Phenomena Matrix
  + Updated translations.
* Mon Jun 16 2008 maw@suse.de
- Update to version 2.23.3:
  + libgweather:
  * Parse the localized Locations.xml if available
  * When parsing Locations.xml, merge a city with its location
    when there's only one location
  * Do not keep region/country/state/city without locations
  + Locations.xml:
  * Updated Russian tz-hints
  * Add correct tz-hint for Valparaiso, IN
  * Fix many tz-hints
  * Add script to check the tz-hints are valid
  * Add some documentation about the format of the file
  * Create per-locale XML files if asked so to improve
    performance
  * Divide Mexico locations into states
  * Update data for Santiago
  * Fix coordinates for Nefta
  * Added the East-Flanders region of Belgium
  * Complete the entries for New Zealand
  * Fix Louisiana spelling
  + Misc:
  * Add new --enable-all-translations-in-one-xml configure flag to keep
    the old behavior of building one XML file with all translations
    instead of creating per-locale XML files
  * List the right libraries requirements in gweather.pc
  * Fix build when LINGUAS is set
  * Fix build with -jX
  + Updated translations.
* Mon Apr 14 2008 coolo@suse.de
- fix also xxbit
* Thu Apr 10 2008 maw@suse.de
- libgweather needs to require libgweather1, not libgweather0.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Apr  9 2008 maw@suse.de
- Update to version 2.22.1.1:
  + The API/ABI has been broken in this release, leading to a
    soname update and libgweather0 being renamed to libgweather1
  + libgweather:
  * Add API to parse Locations.xml, based on the code from
    gnome-applets/gnome-panel
  * Parse country codes and timezone hints (this is what breaks
    API/ABI)
  + Locations.xml
  * Add country codes and timezone hints to Locations.xml
  * Make the file valid
  * Add make check rule
  + Misc:
  * Distribute Locations.xml.in and relevant translations
  + Updated translations.
* Fri Mar 14 2008 maw@suse.de
- Update to version 2.22.0:
  + Updated translations.
* Tue Mar  4 2008 maw@suse.de
- Update to version 2.21.92:
  + Updated translations.
* Tue Jan 22 2008 maw@suse.de
- The -devel subpackage provides what used to be included in
  gnome-applets-devel, so Provide/Obsolete that package
- Since gnome-applets-devel provided and obsoleted gswitchit-devel,
  we now do the same in libgweather-devel.
* Thu Jan 17 2008 maw@suse.de
- Update to version 2.21.2:
  + Minor fixes with respect to 2.21.1.
* Mon Jan  7 2008 federico@novell.com
- First version of the libgweather package.
